@@ -21,6 +21,7 @@ MA 02110-1301 USA
 #ifndef NEPIM_CONF_H
 #define NEPIM_CONF_H
 
+#include <stdio.h>
 #include <oop.h>
 
 #include "usec.h"
@@ -28,6 +29,7 @@ MA 02110-1301 USA
 typedef struct nepim_global_t nepim_global_t;
 
 struct nepim_global_t {
+  FILE         *verbose_stderr; /* stream for verbose error messages */
   const char   *prog_name;
   char         *hostname;
   int           client_mode;
